import { NodeOptions } from '@sentry/node';
import { SeverityLevel, ScopeContext } from '@sentry/types';
import { SResponseOKBasic, SResponseKOObject, SResponseOKObject, SResponseKOSimple, SResponseKOObjectSimple } from 'oro-functions';

interface OSentryLevelObject {
    LOG: 'log';
    INFO: 'info';
    DEBUG: 'debug';
    WARNING: 'warning';
    ERROR: 'error';
    FATAL: 'fatal';
}
interface OSentryConfigOptions extends NodeOptions {
    normalizeDepth?: number;
}
interface OSentryConfig {
    dsn?: string;
    sentryDsn?: string;
    environment?: string;
    projectname?: string;
    projectserver?: string;
    defaultTags?: string[];
    autoInit?: boolean;
    options?: OSentryConfigOptions;
}
interface OSentryInitError {
    msg: string;
    sentry?: Error;
}
type OSentryInitResponse = SResponseOKBasic | SResponseKOObject<OSentryInitError>;
interface OSentryResponseDefaultParams {
    msg?: string;
    message?: string;
    level?: SeverityLevel;
    user?: Partial<ScopeContext['user']>;
    tags?: ScopeContext['tags'];
    projectserver?: string;
    projectname?: string;
}
type OSentryResponse<T extends Record<string, any>> = SResponseOKObject<OSentryResponseDefaultParams & T> | SResponseKOSimple | SResponseKOObject<OSentryResponseDefaultParams & T> | SResponseKOObjectSimple<OSentryResponseDefaultParams & T>;
interface OSentrySendObject {
    event: {
        id: string;
        message: string;
        captureContext: Partial<ScopeContext>;
    };
}
type OSentrySendResponse = SResponseOKObject<OSentrySendObject> | SResponseKOSimple;
declare class OSentry {
    #private;
    static LEVEL: OSentryLevelObject;
    static getClient(): any;
    defaultTags: string[];
    projectname?: string;
    projectserver?: string;
    constructor({ dsn, sentryDsn, environment, projectname, projectserver, defaultTags, autoInit, options, }?: OSentryConfig);
    get status(): boolean;
    get environment(): string;
    getClient(): any;
    getOptions(): OSentryConfigOptions;
    init(options?: OSentryConfigOptions): OSentryInitResponse;
    sendResponse<T extends Record<string, any>>(response: OSentryResponse<T>, inConsole?: boolean): OSentrySendResponse;
    captureMessage(message: string, captureContext: Partial<ScopeContext>): OSentrySendResponse;
}

export { OSentry, OSentryConfig, OSentryConfigOptions, OSentryInitError, OSentryInitResponse, OSentryLevelObject, OSentryResponse, OSentryResponseDefaultParams, OSentrySendObject, OSentrySendResponse, OSentry as default };
